const debug = require("debug")("ldi");

const program = require("commander");
const yaml = require("js-yaml");
const color = require("colors");
const { readEncrypted } = require("seno-encryptor");
const K8Config = require("kubernetes-client").config;
const K8Client = require("kubernetes-client").Client;

program
  .command("ls")
  .description("get kubernetes pod status")
  .action(async () => {
    try {
      const kubeCfg = yaml.safeLoad(await readEncrypted("kube.cfg"));
      const results = await Promise.all(
        mods.map(async mod => {
          const config = K8Config.fromKubeconfig(kubeCfg[mod.config]);
          const client = new K8Client({ config });
          client.backend.requestOptions.strictSSL = false;
          await client.loadSpec();
          const pods = (await client.api.v1
            .namespaces(mod.namespace)
            .pods.get()).body.items.reduce((acc, pod) => {
            acc[pod.metadata.labels.app] = pod;
            return acc;
          }, {});
          return {
            ...mod,
            pods
          };
        })
      );
      for (const mod of results) {
        console.log(`${color.blue(mod.id)}`);
        for (const podName of mod.items) {
          const pod = mod.pods[podName];
          if (pod) {
            const container = pod.spec.containers.filter(
              c => c.name !== "packetbeat"
            )[0];
            const status = pod.status.phase;
            console.log(
              `   ${color.blue(podName)}: ${
                status === "Running" ? color.green(status) : color.red(status)
              }`
            );
            console.log(`      ${container.image}`);
          } else {
            console.log(
              `   ${color.blue(podName)}: ${color.red("Not running")}`
            );
          }
        }
      }
    } catch (err) {
      console.error(err);
      process.exit(1);
    }
  });

const mods = [
  {
    id: "test",
    config: "dev",
    namespace: "p2plending-test",
    items: [
      "account",
      "common",
      "investment",
      "loan",
      "logstash",
      "mongo",
      "mongo-express",
      "param",
      "payment-bni",
      "redis",
      "report",
      "wallet"
    ]
  },
  {
    id: "dev",
    config: "dev",
    namespace: "p2plending-dev",
    items: [
      "account",
      "addin",
      "client-backoffice",
      "client-nasabah",
      "common",
      "docker-registry",
      "investment",
      "jenkins",
      "jsreport2",
      "loan",
      "logstash",
      "mongo",
      "mongo-express",
      "param",
      "payment-bni",
      "redis",
      "report",
      "wallet"
    ]
  },
  {
    id: "prod",
    config: "prod",
    namespace: "prod",
    items: [
      "account",
      "addin",
      "client-backoffice",
      "client-nasabah",
      "common",
      "investment",
      "jsreport",
      "loan",
      "logstash",
      "mongo",
      "mongo-express",
      "param",
      "redis",
      "report",
      "wallet"
    ]
  }
];

program.on("command:*", () => {
  program.help();
  process.exit(1);
});

if (process.argv.length <= 2) {
  program.help();
  process.exit(1);
}

program.parse(process.argv);
